@@ -1,4 +1,4 @@
-"""Utilities to get configurable parameters."""
+"""Utilities for parsing model configuration."""
 
 # Copyright (C) 2020 Intel Corporation
 #
@@ -20,4 +20,4 @@ from .config import (
     update_nncf_config,
 )
 
-__all__ = ["get_configurable_parameters", "update_input_size_config", "update_nncf_config"]
+__all__ = ["get_configurable_parameters", "update_nncf_config", "update_input_size_config"]
