@@ -161,12 +161,13 @@ def get_configurable_parameters(
     config.trainer.default_root_dir = str(project_path)
 
     if weight_file:
-        config.model.weight_file = weight_file
+        config.trainer.resume_from_checkpoint = weight_file
 
     config = update_nncf_config(config)
 
     # thresholding
-    if "pixel_default" not in config.model.threshold.keys():
-        config.model.threshold.pixel_default = config.model.threshold.image_default
+    if "metrics" in config.keys():
+        if "pixel_default" not in config.metrics.threshold.keys():
+            config.metrics.threshold.pixel_default = config.metrics.threshold.image_default
 
     return config
