@@ -27,6 +27,7 @@ import cv2
 import numpy as np
 from pandas.core.frame import DataFrame
 from pytorch_lightning.core.datamodule import LightningDataModule
+from pytorch_lightning.utilities.cli import DATAMODULE_REGISTRY
 from pytorch_lightning.utilities.types import EVAL_DATALOADERS, TRAIN_DATALOADERS
 from torch import Tensor
 from torch.utils.data import DataLoader, Dataset
@@ -94,7 +95,7 @@ def make_dataset(
     mask_dir: Optional[Union[str, Path]] = None,
     split: Optional[str] = None,
     split_ratio: float = 0.2,
-    seed: int = 0,
+    seed: Optional[int] = None,
     create_validation_set: bool = True,
     extensions: Optional[Tuple[str, ...]] = None,
 ):
@@ -190,7 +191,7 @@ class FolderDataset(Dataset):
         mask_dir: Optional[Union[Path, str]] = None,
         extensions: Optional[Tuple[str, ...]] = None,
         task: Optional[str] = None,
-        seed: int = 0,
+        seed: Optional[int] = None,
         create_validation_set: bool = False,
     ) -> None:
         """Create Folder Folder Dataset.
@@ -301,7 +302,8 @@ class FolderDataset(Dataset):
         return item
 
 
-class FolderDataModule(LightningDataModule):
+@DATAMODULE_REGISTRY
+class Folder(LightningDataModule):
     """Folder Lightning Data Module."""
 
     def __init__(
@@ -314,7 +316,7 @@ class FolderDataModule(LightningDataModule):
         mask_dir: Optional[Union[Path, str]] = None,
         extensions: Optional[Tuple[str, ...]] = None,
         split_ratio: float = 0.2,
-        seed: int = 0,
+        seed: Optional[int] = None,
         image_size: Optional[Union[int, Tuple[int, int]]] = None,
         train_batch_size: int = 32,
         test_batch_size: int = 32,
@@ -359,8 +361,8 @@ class FolderDataModule(LightningDataModule):
 
         Examples:
             Assume that we use Folder Dataset for the MVTec/bottle/broken_large category. We would do:
-            >>> from anomalib.data import FolderDataModule
-            >>> datamodule = FolderDataModule(
+            >>> from anomalib.data import Folder
+            >>> datamodule = Folder(
             ...     root="./datasets/MVTec/bottle/test",
             ...     normal="good",
             ...     abnormal="broken_large",
@@ -379,7 +381,7 @@ class FolderDataModule(LightningDataModule):
             The dataset expects that mask annotation filenames must be same as the original filename.
             To this end, we modified mask filenames in MVTec AD bottle category.
             Now we could try folder data module using the mvtec bottle broken large category
-            >>> datamodule = FolderDataModule(
+            >>> datamodule = Folder(
             ...     root="./datasets/bottle/test",
             ...     normal="good",
             ...     abnormal="broken_large",
@@ -401,7 +403,7 @@ class FolderDataModule(LightningDataModule):
             By default, Folder Data Module does not create a validation set. If a validation set
             is needed it could be set as follows:
 
-            >>> datamodule = FolderDataModule(
+            >>> datamodule = Folder(
             ...     root="./datasets/bottle/test",
             ...     normal="good",
             ...     abnormal="broken_large",
@@ -423,6 +425,13 @@ class FolderDataModule(LightningDataModule):
         """
         super().__init__()
 
+        if seed is None and normal_test_dir is None:
+            raise ValueError(
+                "Both seed and normal_test_dir cannot be None."
+                " When seed is not set, images from the normal directory are split between training and test dir."
+                " This will lead to inconsistency between runs."
+            )
+
         self.root = _check_and_convert_path(root)
         self.normal_dir = self.root / normal_dir
         self.abnormal_dir = self.root / abnormal_dir
