@@ -14,8 +14,8 @@
 # See the License for the specific language governing permissions
 # and limitations under the License.
 
-from .base import Inferencer
-from .openvino import OpenVINOInferencer
-from .torch import TorchInferencer
+from .base_inferencer import Inferencer
+from .openvino_inferencer import OpenVINOInferencer
+from .torch_inferencer import TorchInferencer
 
-__all__ = ["Inferencer", "TorchInferencer", "OpenVINOInferencer"]
+__all__ = ["Inferencer", "OpenVINOInferencer", "TorchInferencer"]
