@@ -14,6 +14,6 @@
 # See the License for the specific language governing permissions
 # and limitations under the License.
 
-from .lightning_model import CflowLightning
+from .lightning_model import Cflow, CflowLightning
 
-__all__ = ["CflowLightning"]
+__all__ = ["Cflow", "CflowLightning"]
