@@ -14,6 +14,6 @@
 # See the License for the specific language governing permissions
 # and limitations under the License.
 
-from .lightning_model import DfkdeLightning
+from .lightning_model import Dfkde, DfkdeLightning
 
-__all__ = ["DfkdeLightning"]
+__all__ = ["Dfkde", "DfkdeLightning"]
