@@ -14,6 +14,6 @@
 # See the License for the specific language governing permissions
 # and limitations under the License.
 
-from .lightning_model import PadimLightning
+from .lightning_model import Padim, PadimLightning
 
-__all__ = ["PadimLightning"]
+__all__ = ["Padim", "PadimLightning"]
