@@ -14,6 +14,6 @@
 # See the License for the specific language governing permissions
 # and limitations under the License.
 
-from .lightning_model import PatchcoreLightning
+from .lightning_model import Patchcore, PatchcoreLightning
 
-__all__ = ["PatchcoreLightning"]
+__all__ = ["Patchcore", "PatchcoreLightning"]
