@@ -22,10 +22,12 @@ from nncf import NNCFConfig
 from nncf.api.compression import CompressionAlgorithmController
 from nncf.torch import register_default_init_args
 from pytorch_lightning import Callback
+from pytorch_lightning.utilities.cli import CALLBACK_REGISTRY
 
 from anomalib.utils.callbacks.nncf.utils import InitLoader, wrap_nncf_model
 
 
+@CALLBACK_REGISTRY
 class NNCFCallback(Callback):
     """Callback for NNCF compression.
 
